@@ -12,6 +12,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredE
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -19,10 +20,10 @@ import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
 
 public class CloneTabularResource implements MonitorDialogListener {
-	protected TRId trId;
-	protected EventBus eventBus;
+	private TRId trId;
+	private EventBus eventBus;
 
-	protected CloneTabularResourceSession cloneTabularResourceSession;
+	private CloneTabularResourceSession cloneTabularResourceSession;
 
 	public CloneTabularResource(TRId trId, EventBus eventBus) {
 		this.trId = trId;
@@ -53,7 +54,7 @@ public class CloneTabularResource implements MonitorDialogListener {
 										+ caught.getLocalizedMessage());
 								UtilsGXT3.alert(
 										"Error Cloning Tabular Resource",
-										"Error in clone operation!");
+										"Error in clone operation! "+caught.getLocalizedMessage());
 							}
 						}
 					}
@@ -81,10 +82,10 @@ public class CloneTabularResource implements MonitorDialogListener {
 	}
 
 	@Override
-	public void operationComplete(TRId trId) {
-		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
+	public void operationComplete(OperationResult operationResult) {
+		ChangeTableWhy why = ChangeTableWhy.TABLECLONED;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.CLONETABULARRESOURCE, trId, why);
+				ChangeTableRequestType.CLONETABULARRESOURCE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 	}
@@ -97,10 +98,10 @@ public class CloneTabularResource implements MonitorDialogListener {
 	}
 
 	@Override
-	public void operationStopped(TRId trId, String reason, String details) {
+	public void operationStopped(OperationResult operationResult, String reason, String details) {
 		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.CLONETABULARRESOURCE, trId, why);
+				ChangeTableRequestType.CLONETABULARRESOURCE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 
